@@ -1,7 +1,8 @@
 use crate::api::ApiClient;
+use crate::util::fail;
 use std::fs::{canonicalize, read_to_string, remove_file, OpenOptions};
 use std::io::{ErrorKind, Write};
-use std::process::{exit, Command};
+use std::process::Command;
 
 pub async fn connect<'a>(
     client: &ApiClient,
@@ -34,25 +35,21 @@ pub async fn connect<'a>(
     // Read public key to file
     let contents = match read_to_string(&public_path) {
         Ok(contents) => contents,
-        Err(e) => {
-            println!(
-                "Failed to read public key '{}': {}",
-                public_path.as_path().to_str().unwrap(),
-                e
-            );
-            exit(1);
-        }
+        Err(e) => fail(&format!(
+            "Failed to read public key '{}': {}",
+            public_path.as_path().to_str().unwrap(),
+            e
+        )),
     };
 
     // Sign the public key
     let signed = match client.sign(role.to_string(), contents).await {
         Ok(signed) => signed,
-        Err(e) => {
-            println!("Failed to sign public key: {}", e);
-            exit(1);
-        }
+        Err(e) => fail(&format!("Failed to sign public key: {}", e)),
     };
 
+    leg::success("Signed public key with role", None, None);
+
     // Create output file
     let name = crate::util::random_string(16);
     let mut file = match OpenOptions::new()
@@ -64,23 +61,21 @@ pub async fn connect<'a>(
         Err(e) => {
             match e.kind() {
                 ErrorKind::PermissionDenied => {
-                    println!("Cannot write signed public key: permission denied")
+                    fail("Cannot write signed public key: permission denied")
                 }
-                _ => println!("Failed to open output file: {}", e),
+                _ => fail(&format!("Failed to open output file: {}", e)),
             };
-            exit(1);
         }
     };
 
     // Write to file
     match file.write_all(signed.as_bytes()) {
         Ok(_) => {}
-        Err(e) => {
-            println!("Failed to write to output file: {}", e);
-            exit(1);
-        }
+        Err(e) => fail(&format!("Failed to write to output file: {}", e)),
     }
 
+    leg::success("Wrote signed public key to temporary file", None, None);
+
     // Run command
     let mut child = match Command::new("ssh")
         .arg("-i")
@@ -92,26 +87,24 @@ pub async fn connect<'a>(
         .spawn()
     {
         Ok(child) => child,
-        Err(e) => {
-            println!("Failed to start ssh command: {}", e);
-            exit(1);
-        }
+        Err(e) => fail(&format!("Failed to start ssh command: {}", e)),
     };
 
+    leg::wait("Running SSH command...", None, None);
+
     // Bring to foreground
     child.wait().expect("Failed to wait on child");
 
     // Remove signed certificate
     match remove_file(format!("/tmp/{}", name)) {
-        Ok(_) => {}
+        Ok(_) => leg::success("Cleaned up signed public key", None, None),
         Err(e) => {
             match e.kind() {
                 ErrorKind::PermissionDenied => {
-                    println!("Cannot remove signed certificate: permission denied")
+                    fail("Cannot remove signed certificate: permission denied")
                 }
-                _ => println!("Failed to remove signed certificate: {}", e),
+                _ => fail(&format!("Failed to remove signed certificate: {}", e)),
             };
-            exit(1);
         }
     };
 }
@@ -122,10 +115,12 @@ fn ensure_exists(path: &str) -> std::path::PathBuf {
         Ok(path) => path,
         Err(e) => {
             match e.kind() {
-                ErrorKind::NotFound => println!("File '{}' does not exist", path),
-                _ => println!("Failed to convert relative to absolute path: {}", e),
+                ErrorKind::NotFound => fail(&format!("File '{}' does not exist", path)),
+                _ => fail(&format!(
+                    "Failed to convert relative to absolute path: {}",
+                    e
+                )),
             };
-            exit(1);
         }
     }
 }
